pub trait Profile:
PartialEq
+ Debug
+ Eq
+ Clone {
// Provided method
fn check_serial_number(serial: &SerialNumber<Self>) -> Result<()> { ... }
}Expand description
Profile allows the consumer of this crate to customize the behavior when parsing
certificates.
By default, parsing will be made in a rfc5280-compliant manner.
Provided Methods
Sourcefn check_serial_number(serial: &SerialNumber<Self>) -> Result<()>
fn check_serial_number(serial: &SerialNumber<Self>) -> Result<()>
Checks to run when parsing serial numbers
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".