pub struct CertificatePolicies(pub Vec<PolicyInformation>);Expand description
CertificatePolicies as defined in RFC 5280 Section 4.2.1.4.
CertificatePolicies ::= SEQUENCE SIZE (1..MAX) OF PolicyInformationTuple Fields
0: Vec<PolicyInformation>Trait Implementations
Sourceimpl AsExtension for CertificatePolicies
impl AsExtension for CertificatePolicies
Sourceimpl<'a> AsMut<Vec<PolicyInformation>> for CertificatePolicies
impl<'a> AsMut<Vec<PolicyInformation>> for CertificatePolicies
Sourcefn as_mut(&mut self) -> &mut Vec<PolicyInformation>
fn as_mut(&mut self) -> &mut Vec<PolicyInformation>
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<PolicyInformation>> for CertificatePolicies
impl<'a> AsRef<Vec<PolicyInformation>> for CertificatePolicies
Sourcefn as_ref(&self) -> &Vec<PolicyInformation>
fn as_ref(&self) -> &Vec<PolicyInformation>
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for CertificatePolicies
impl AssociatedOid for CertificatePolicies
Sourceconst OID: ObjectIdentifier = ID_CE_CERTIFICATE_POLICIES
const OID: ObjectIdentifier = ID_CE_CERTIFICATE_POLICIES
The OID associated with this type.
Sourceimpl Clone for CertificatePolicies
impl Clone for CertificatePolicies
Sourcefn clone(&self) -> CertificatePolicies
fn clone(&self) -> CertificatePolicies
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CertificatePolicies
impl Debug for CertificatePolicies
Sourceimpl<'a> DecodeValue<'a> for CertificatePolicies
impl<'a> DecodeValue<'a> for CertificatePolicies
Sourcefn decode_value<R: Reader<'a>>(decoder: &mut R, header: Header) -> Result<Self>
fn decode_value<R: Reader<'a>>(decoder: &mut R, header: Header) -> Result<Self>
Attempt to decode this message using the provided [
Reader].Sourceimpl<'a> EncodeValue for CertificatePolicies
impl<'a> EncodeValue for CertificatePolicies
Sourceimpl<'a> FixedTag for CertificatePolicies
impl<'a> FixedTag for CertificatePolicies
Sourceimpl<'a> From<CertificatePolicies> for Vec<PolicyInformation>
impl<'a> From<CertificatePolicies> for Vec<PolicyInformation>
Sourcefn from(value: CertificatePolicies) -> Self
fn from(value: CertificatePolicies) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<Vec<PolicyInformation>> for CertificatePolicies
impl<'a> From<Vec<PolicyInformation>> for CertificatePolicies
Sourcefn from(value: Vec<PolicyInformation>) -> Self
fn from(value: Vec<PolicyInformation>) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for CertificatePolicies
impl PartialEq for CertificatePolicies
Sourcefn eq(&self, other: &CertificatePolicies) -> bool
fn eq(&self, other: &CertificatePolicies) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'a> ValueOrd for CertificatePolicies
impl<'a> ValueOrd for CertificatePolicies
impl Eq for CertificatePolicies
impl StructuralPartialEq for CertificatePolicies