pub struct NoticeReference {
pub organization: DisplayText,
pub notice_numbers: Option<Vec<Uint>>,
}Expand description
NoticeReference as defined in RFC 5280 Section 4.2.1.4.
NoticeReference ::= SEQUENCE {
organization DisplayText,
noticeNumbers SEQUENCE OF INTEGER }Fields
organization: DisplayTextnotice_numbers: Option<Vec<Uint>>Trait Implementations
Sourceimpl Clone for NoticeReference
impl Clone for NoticeReference
Sourcefn clone(&self) -> NoticeReference
fn clone(&self) -> NoticeReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NoticeReference
impl Debug for NoticeReference
Sourceimpl<'__der_lifetime> DecodeValue<'__der_lifetime> for NoticeReference
impl<'__der_lifetime> DecodeValue<'__der_lifetime> for NoticeReference
Sourcefn decode_value<R: Reader<'__der_lifetime>>(
reader: &mut R,
header: Header,
) -> Result<Self>
fn decode_value<R: Reader<'__der_lifetime>>( reader: &mut R, header: Header, ) -> Result<Self>
Attempt to decode this message using the provided [
Reader].Sourceimpl<'__der_lifetime> EncodeValue for NoticeReference
impl<'__der_lifetime> EncodeValue for NoticeReference
Sourceimpl PartialEq for NoticeReference
impl PartialEq for NoticeReference
Sourcefn eq(&self, other: &NoticeReference) -> bool
fn eq(&self, other: &NoticeReference) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for NoticeReference
impl<'__der_lifetime> Sequence<'__der_lifetime> for NoticeReference
impl StructuralPartialEq for NoticeReference