pub struct UserNotice {
pub notice_ref: Option<GeneralizedTime>,
pub explicit_text: Option<DisplayText>,
}Expand description
UserNotice as defined in RFC 5280 Section 4.2.1.4.
UserNotice ::= SEQUENCE {
noticeRef NoticeReference OPTIONAL,
explicitText DisplayText OPTIONAL
}Fields
notice_ref: Option<GeneralizedTime>explicit_text: Option<DisplayText>Trait Implementations
Sourceimpl Clone for UserNotice
impl Clone for UserNotice
Sourcefn clone(&self) -> UserNotice
fn clone(&self) -> UserNotice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserNotice
impl Debug for UserNotice
Sourceimpl<'__der_lifetime> DecodeValue<'__der_lifetime> for UserNotice
impl<'__der_lifetime> DecodeValue<'__der_lifetime> for UserNotice
Sourcefn decode_value<R: Reader<'__der_lifetime>>(
reader: &mut R,
header: Header,
) -> Result<Self>
fn decode_value<R: Reader<'__der_lifetime>>( reader: &mut R, header: Header, ) -> Result<Self>
Attempt to decode this message using the provided [
Reader].Sourceimpl<'__der_lifetime> EncodeValue for UserNotice
impl<'__der_lifetime> EncodeValue for UserNotice
Sourceimpl PartialEq for UserNotice
impl PartialEq for UserNotice
Sourcefn eq(&self, other: &UserNotice) -> bool
fn eq(&self, other: &UserNotice) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UserNotice
impl<'__der_lifetime> Sequence<'__der_lifetime> for UserNotice
impl StructuralPartialEq for UserNotice