pub struct GeneralSubtree {
pub base: GeneralName,
pub minimum: u32,
pub maximum: Option<u32>,
}Expand description
GeneralSubtree as defined in RFC 5280 Section 4.2.1.10.
GeneralSubtree ::= SEQUENCE {
base GeneralName,
minimum [0] BaseDistance DEFAULT 0,
maximum [1] BaseDistance OPTIONAL
}Fields
base: GeneralNameminimum: u32maximum: Option<u32>Trait Implementations
Sourceimpl Clone for GeneralSubtree
impl Clone for GeneralSubtree
Sourcefn clone(&self) -> GeneralSubtree
fn clone(&self) -> GeneralSubtree
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GeneralSubtree
impl Debug for GeneralSubtree
Sourceimpl<'__der_lifetime> DecodeValue<'__der_lifetime> for GeneralSubtree
impl<'__der_lifetime> DecodeValue<'__der_lifetime> for GeneralSubtree
Sourcefn decode_value<R: Reader<'__der_lifetime>>(
reader: &mut R,
header: Header,
) -> Result<Self>
fn decode_value<R: Reader<'__der_lifetime>>( reader: &mut R, header: Header, ) -> Result<Self>
Attempt to decode this message using the provided [
Reader].Sourceimpl<'__der_lifetime> EncodeValue for GeneralSubtree
impl<'__der_lifetime> EncodeValue for GeneralSubtree
Sourceimpl PartialEq for GeneralSubtree
impl PartialEq for GeneralSubtree
Sourcefn eq(&self, other: &GeneralSubtree) -> bool
fn eq(&self, other: &GeneralSubtree) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for GeneralSubtree
impl<'__der_lifetime> Sequence<'__der_lifetime> for GeneralSubtree
impl StructuralPartialEq for GeneralSubtree