pub struct EdiPartyName {
pub name_assigner: Option<DirectoryString>,
pub party_name: DirectoryString,
}Expand description
EDIPartyName as defined in RFC 5280 Section 4.2.1.6.
EDIPartyName ::= SEQUENCE {
nameAssigner [0] DirectoryString OPTIONAL,
partyName [1] DirectoryString
}Note that although the module uses IMPLICIT tagging, these tags are
EXPLICIT because of X.680-2015 31.2.7 (c):
c) the "Tag Type" alternative is used and the value of "TagDefault" for
the module is IMPLICIT TAGS or AUTOMATIC TAGS, but the type defined by
"Type" is an untagged choice type, an untagged open type, or an untagged
"DummyReference" (see Rec. ITU-T X.683 | ISO/IEC 8824-4, 8.3).See this OpenSSL bug for more details.
Fields
name_assigner: Option<DirectoryString>party_name: DirectoryStringTrait Implementations
Sourceimpl Clone for EdiPartyName
impl Clone for EdiPartyName
Sourcefn clone(&self) -> EdiPartyName
fn clone(&self) -> EdiPartyName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EdiPartyName
impl Debug for EdiPartyName
Sourceimpl<'__der_lifetime> DecodeValue<'__der_lifetime> for EdiPartyName
impl<'__der_lifetime> DecodeValue<'__der_lifetime> for EdiPartyName
Sourcefn decode_value<R: Reader<'__der_lifetime>>(
reader: &mut R,
header: Header,
) -> Result<Self>
fn decode_value<R: Reader<'__der_lifetime>>( reader: &mut R, header: Header, ) -> Result<Self>
Attempt to decode this message using the provided [
Reader].Sourceimpl<'__der_lifetime> EncodeValue for EdiPartyName
impl<'__der_lifetime> EncodeValue for EdiPartyName
Sourceimpl PartialEq for EdiPartyName
impl PartialEq for EdiPartyName
Sourcefn eq(&self, other: &EdiPartyName) -> bool
fn eq(&self, other: &EdiPartyName) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ValueOrd for EdiPartyName
impl ValueOrd for EdiPartyName
impl Eq for EdiPartyName
impl<'__der_lifetime> Sequence<'__der_lifetime> for EdiPartyName
impl StructuralPartialEq for EdiPartyName