pub struct AccessDescription {
pub access_method: ObjectIdentifier,
pub access_location: GeneralName,
}Expand description
AccessDescription as defined in RFC 5280 Section 4.2.2.1.
AccessDescription ::= SEQUENCE {
accessMethod OBJECT IDENTIFIER,
accessLocation GeneralName
}Fields
access_method: ObjectIdentifieraccess_location: GeneralNameTrait Implementations
Sourceimpl Clone for AccessDescription
impl Clone for AccessDescription
Sourcefn clone(&self) -> AccessDescription
fn clone(&self) -> AccessDescription
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccessDescription
impl Debug for AccessDescription
Sourceimpl<'__der_lifetime> DecodeValue<'__der_lifetime> for AccessDescription
impl<'__der_lifetime> DecodeValue<'__der_lifetime> for AccessDescription
Sourcefn decode_value<R: Reader<'__der_lifetime>>(
reader: &mut R,
header: Header,
) -> Result<Self>
fn decode_value<R: Reader<'__der_lifetime>>( reader: &mut R, header: Header, ) -> Result<Self>
Attempt to decode this message using the provided [
Reader].Sourceimpl<'__der_lifetime> EncodeValue for AccessDescription
impl<'__der_lifetime> EncodeValue for AccessDescription
Sourceimpl PartialEq for AccessDescription
impl PartialEq for AccessDescription
Sourcefn eq(&self, other: &AccessDescription) -> bool
fn eq(&self, other: &AccessDescription) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ValueOrd for AccessDescription
impl ValueOrd for AccessDescription
impl Eq for AccessDescription
impl<'__der_lifetime> Sequence<'__der_lifetime> for AccessDescription
impl StructuralPartialEq for AccessDescription