pub struct InhibitAnyPolicy(pub u32);Expand description
InhibitAnyPolicy as defined in RFC 5280 Section 4.2.1.14.
InhibitAnyPolicy ::= SkipCertsTuple Fields
0: u32Trait Implementations
Sourceimpl AsExtension for InhibitAnyPolicy
impl AsExtension for InhibitAnyPolicy
Sourceimpl<'a> AsMut<u32> for InhibitAnyPolicy
impl<'a> AsMut<u32> for InhibitAnyPolicy
Sourceimpl<'a> AsRef<u32> for InhibitAnyPolicy
impl<'a> AsRef<u32> for InhibitAnyPolicy
Sourceimpl AssociatedOid for InhibitAnyPolicy
impl AssociatedOid for InhibitAnyPolicy
Sourceconst OID: ObjectIdentifier = ID_CE_INHIBIT_ANY_POLICY
const OID: ObjectIdentifier = ID_CE_INHIBIT_ANY_POLICY
The OID associated with this type.
Sourceimpl Clone for InhibitAnyPolicy
impl Clone for InhibitAnyPolicy
Sourcefn clone(&self) -> InhibitAnyPolicy
fn clone(&self) -> InhibitAnyPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InhibitAnyPolicy
impl Debug for InhibitAnyPolicy
Sourceimpl<'a> DecodeValue<'a> for InhibitAnyPolicy
impl<'a> DecodeValue<'a> for InhibitAnyPolicy
Sourcefn decode_value<R: Reader<'a>>(decoder: &mut R, header: Header) -> Result<Self>
fn decode_value<R: Reader<'a>>(decoder: &mut R, header: Header) -> Result<Self>
Attempt to decode this message using the provided [
Reader].Sourceimpl Default for InhibitAnyPolicy
impl Default for InhibitAnyPolicy
Sourcefn default() -> InhibitAnyPolicy
fn default() -> InhibitAnyPolicy
Returns the “default value” for a type. Read more
Sourceimpl<'a> EncodeValue for InhibitAnyPolicy
impl<'a> EncodeValue for InhibitAnyPolicy
Sourceimpl<'a> FixedTag for InhibitAnyPolicy
impl<'a> FixedTag for InhibitAnyPolicy
Sourceimpl<'a> From<InhibitAnyPolicy> for u32
impl<'a> From<InhibitAnyPolicy> for u32
Sourcefn from(value: InhibitAnyPolicy) -> Self
fn from(value: InhibitAnyPolicy) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<u32> for InhibitAnyPolicy
impl<'a> From<u32> for InhibitAnyPolicy
Sourceimpl PartialEq for InhibitAnyPolicy
impl PartialEq for InhibitAnyPolicy
Sourcefn eq(&self, other: &InhibitAnyPolicy) -> bool
fn eq(&self, other: &InhibitAnyPolicy) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'a> ValueOrd for InhibitAnyPolicy
impl<'a> ValueOrd for InhibitAnyPolicy
impl Copy for InhibitAnyPolicy
impl Eq for InhibitAnyPolicy
impl StructuralPartialEq for InhibitAnyPolicy