pub struct IssuerAltName(pub GeneralNames);Expand description
IssuerAltName as defined in RFC 5280 Section 4.2.1.7.
IssuerAltName ::= GeneralNamesTuple Fields
0: GeneralNamesTrait Implementations
Sourceimpl AsExtension for IssuerAltName
impl AsExtension for IssuerAltName
Sourceimpl<'a> AsMut<Vec<GeneralName>> for IssuerAltName
impl<'a> AsMut<Vec<GeneralName>> for IssuerAltName
Sourcefn as_mut(&mut self) -> &mut GeneralNames
fn as_mut(&mut self) -> &mut GeneralNames
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<GeneralName>> for IssuerAltName
impl<'a> AsRef<Vec<GeneralName>> for IssuerAltName
Sourcefn as_ref(&self) -> &GeneralNames
fn as_ref(&self) -> &GeneralNames
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for IssuerAltName
impl AssociatedOid for IssuerAltName
Sourceconst OID: ObjectIdentifier = ID_CE_ISSUER_ALT_NAME
const OID: ObjectIdentifier = ID_CE_ISSUER_ALT_NAME
The OID associated with this type.
Sourceimpl Clone for IssuerAltName
impl Clone for IssuerAltName
Sourcefn clone(&self) -> IssuerAltName
fn clone(&self) -> IssuerAltName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IssuerAltName
impl Debug for IssuerAltName
Sourceimpl<'a> DecodeValue<'a> for IssuerAltName
impl<'a> DecodeValue<'a> for IssuerAltName
Sourcefn decode_value<R: Reader<'a>>(decoder: &mut R, header: Header) -> Result<Self>
fn decode_value<R: Reader<'a>>(decoder: &mut R, header: Header) -> Result<Self>
Attempt to decode this message using the provided [
Reader].Sourceimpl Default for IssuerAltName
impl Default for IssuerAltName
Sourcefn default() -> IssuerAltName
fn default() -> IssuerAltName
Returns the “default value” for a type. Read more
Sourceimpl<'a> EncodeValue for IssuerAltName
impl<'a> EncodeValue for IssuerAltName
Sourceimpl<'a> FixedTag for IssuerAltName
impl<'a> FixedTag for IssuerAltName
Sourceimpl<'a> From<IssuerAltName> for GeneralNames
impl<'a> From<IssuerAltName> for GeneralNames
Sourcefn from(value: IssuerAltName) -> Self
fn from(value: IssuerAltName) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<Vec<GeneralName>> for IssuerAltName
impl<'a> From<Vec<GeneralName>> for IssuerAltName
Sourcefn from(value: GeneralNames) -> Self
fn from(value: GeneralNames) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for IssuerAltName
impl PartialEq for IssuerAltName
Sourcefn eq(&self, other: &IssuerAltName) -> bool
fn eq(&self, other: &IssuerAltName) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'a> ValueOrd for IssuerAltName
impl<'a> ValueOrd for IssuerAltName
impl Eq for IssuerAltName
impl StructuralPartialEq for IssuerAltName