pub struct SubjectInfoAccessSyntax(pub Vec<AccessDescription>);Expand description
SubjectInfoAccessSyntax as defined in RFC 5280 Section 4.2.2.2.
SubjectInfoAccessSyntax ::= SEQUENCE SIZE (1..MAX) OF AccessDescriptionTuple Fields
0: Vec<AccessDescription>Trait Implementations
Sourceimpl<'a> AsMut<Vec<AccessDescription>> for SubjectInfoAccessSyntax
impl<'a> AsMut<Vec<AccessDescription>> for SubjectInfoAccessSyntax
Sourcefn as_mut(&mut self) -> &mut Vec<AccessDescription>
fn as_mut(&mut self) -> &mut Vec<AccessDescription>
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<'a> AsRef<Vec<AccessDescription>> for SubjectInfoAccessSyntax
impl<'a> AsRef<Vec<AccessDescription>> for SubjectInfoAccessSyntax
Sourcefn as_ref(&self) -> &Vec<AccessDescription>
fn as_ref(&self) -> &Vec<AccessDescription>
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AssociatedOid for SubjectInfoAccessSyntax
impl AssociatedOid for SubjectInfoAccessSyntax
Sourceconst OID: ObjectIdentifier = ID_PE_SUBJECT_INFO_ACCESS
const OID: ObjectIdentifier = ID_PE_SUBJECT_INFO_ACCESS
The OID associated with this type.
Sourceimpl Clone for SubjectInfoAccessSyntax
impl Clone for SubjectInfoAccessSyntax
Sourcefn clone(&self) -> SubjectInfoAccessSyntax
fn clone(&self) -> SubjectInfoAccessSyntax
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubjectInfoAccessSyntax
impl Debug for SubjectInfoAccessSyntax
Sourceimpl<'a> DecodeValue<'a> for SubjectInfoAccessSyntax
impl<'a> DecodeValue<'a> for SubjectInfoAccessSyntax
Sourcefn decode_value<R: Reader<'a>>(decoder: &mut R, header: Header) -> Result<Self>
fn decode_value<R: Reader<'a>>(decoder: &mut R, header: Header) -> Result<Self>
Attempt to decode this message using the provided [
Reader].Sourceimpl Default for SubjectInfoAccessSyntax
impl Default for SubjectInfoAccessSyntax
Sourcefn default() -> SubjectInfoAccessSyntax
fn default() -> SubjectInfoAccessSyntax
Returns the “default value” for a type. Read more
Sourceimpl<'a> EncodeValue for SubjectInfoAccessSyntax
impl<'a> EncodeValue for SubjectInfoAccessSyntax
Sourceimpl<'a> FixedTag for SubjectInfoAccessSyntax
impl<'a> FixedTag for SubjectInfoAccessSyntax
Sourceimpl<'a> From<SubjectInfoAccessSyntax> for Vec<AccessDescription>
impl<'a> From<SubjectInfoAccessSyntax> for Vec<AccessDescription>
Sourcefn from(value: SubjectInfoAccessSyntax) -> Self
fn from(value: SubjectInfoAccessSyntax) -> Self
Converts to this type from the input type.
Sourceimpl<'a> From<Vec<AccessDescription>> for SubjectInfoAccessSyntax
impl<'a> From<Vec<AccessDescription>> for SubjectInfoAccessSyntax
Sourcefn from(value: Vec<AccessDescription>) -> Self
fn from(value: Vec<AccessDescription>) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SubjectInfoAccessSyntax
impl PartialEq for SubjectInfoAccessSyntax
Sourcefn eq(&self, other: &SubjectInfoAccessSyntax) -> bool
fn eq(&self, other: &SubjectInfoAccessSyntax) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'a> ValueOrd for SubjectInfoAccessSyntax
impl<'a> ValueOrd for SubjectInfoAccessSyntax
impl Eq for SubjectInfoAccessSyntax
impl StructuralPartialEq for SubjectInfoAccessSyntax