pub struct SubjectKeyIdentifier(pub OctetString);Expand description
SubjectKeyIdentifier as defined in RFC 5280 Section 4.2.1.2.
SubjectKeyIdentifier ::= KeyIdentifierTuple Fields
0: OctetStringTrait Implementations
Sourceimpl AsExtension for SubjectKeyIdentifier
impl AsExtension for SubjectKeyIdentifier
Sourceimpl<'a> AsMut<OctetString> for SubjectKeyIdentifier
impl<'a> AsMut<OctetString> for SubjectKeyIdentifier
Sourceimpl<'a> AsRef<OctetString> for SubjectKeyIdentifier
impl<'a> AsRef<OctetString> for SubjectKeyIdentifier
Sourceimpl AssociatedOid for SubjectKeyIdentifier
impl AssociatedOid for SubjectKeyIdentifier
Sourceconst OID: ObjectIdentifier = ID_CE_SUBJECT_KEY_IDENTIFIER
const OID: ObjectIdentifier = ID_CE_SUBJECT_KEY_IDENTIFIER
The OID associated with this type.
Sourceimpl Clone for SubjectKeyIdentifier
impl Clone for SubjectKeyIdentifier
Sourcefn clone(&self) -> SubjectKeyIdentifier
fn clone(&self) -> SubjectKeyIdentifier
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubjectKeyIdentifier
impl Debug for SubjectKeyIdentifier
Sourceimpl<'a> DecodeValue<'a> for SubjectKeyIdentifier
impl<'a> DecodeValue<'a> for SubjectKeyIdentifier
Sourcefn decode_value<R: Reader<'a>>(decoder: &mut R, header: Header) -> Result<Self>
fn decode_value<R: Reader<'a>>(decoder: &mut R, header: Header) -> Result<Self>
Attempt to decode this message using the provided [
Reader].Sourceimpl<'a> EncodeValue for SubjectKeyIdentifier
impl<'a> EncodeValue for SubjectKeyIdentifier
Sourceimpl<'a> FixedTag for SubjectKeyIdentifier
impl<'a> FixedTag for SubjectKeyIdentifier
Sourceimpl<'a> From<OctetString> for SubjectKeyIdentifier
impl<'a> From<OctetString> for SubjectKeyIdentifier
Sourceimpl<'a> From<SubjectKeyIdentifier> for OctetString
impl<'a> From<SubjectKeyIdentifier> for OctetString
Sourcefn from(value: SubjectKeyIdentifier) -> Self
fn from(value: SubjectKeyIdentifier) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SubjectKeyIdentifier
impl PartialEq for SubjectKeyIdentifier
Sourcefn eq(&self, other: &SubjectKeyIdentifier) -> bool
fn eq(&self, other: &SubjectKeyIdentifier) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'a> TryFrom<SubjectPublicKeyInfo<AnyRef<'a>, BitStringRef<'a>>> for SubjectKeyIdentifier
impl<'a> TryFrom<SubjectPublicKeyInfo<AnyRef<'a>, BitStringRef<'a>>> for SubjectKeyIdentifier
Sourceimpl<'a> ValueOrd for SubjectKeyIdentifier
impl<'a> ValueOrd for SubjectKeyIdentifier
impl Eq for SubjectKeyIdentifier
impl StructuralPartialEq for SubjectKeyIdentifier